<?php

/**
 * Represents a custom post type for storing form submissions.
 */
class Lwp_Cfdb_Form_Submission_CPT
{
    //===========================================================================================
    /**
     * Constructor function that registers the custom post type and filters the post row actions.
     */
    public function __construct()
    {
        global  $is_free_version ;
        // Register the custom post type on WordPress 'init' hook.
        add_action( 'init', array( $this, 'register_post_type' ) );
        // Filter the post row actions to disable quick edit for form submissions.
        add_filter(
            'post_row_actions',
            array( $this, 'disable_quick_edit_form_submission' ),
            10,
            1
        );
        //
        if ( $is_free_version ) {
            add_action( 'admin_notices', array( $this, 'free_version_notice' ) );
        }
    }
    
    //===========================================================================================
    /**
     * Registers the custom post type for form submissions.
     */
    public function register_post_type()
    {
        $labels = array(
            'name'               => _x( 'Divi Form DB', 'post type general name' ),
            'singular_name'      => _x( 'Divi Form Submission', 'post type singular name' ),
            'add_new'            => __( 'Add New' ),
            'add_new_item'       => __( 'Add New Divi Form Submission' ),
            'edit_item'          => __( 'View Divi Form Submission' ),
            'new_item'           => __( 'New Divi Form Submission' ),
            'view_item'          => __( 'View Divi Form Submission' ),
            'search_items'       => __( 'Search Divi Form Submissions' ),
            'not_found'          => __( 'No Divi form submissions found' ),
            'not_found_in_trash' => __( 'No Divi form submissions found in Trash' ),
            'parent_item_colon'  => '',
        );
        $args = array(
            'labels'              => $labels,
            'menu_icon'           => 'dashicons-email',
            'public'              => false,
            'exclude_from_search' => true,
            'publicly_queryable'  => false,
            'show_ui'             => true,
            'show_in_nav_menus'   => false,
            'show_in_menu'        => true,
            'query_var'           => true,
            'rewrite'             => false,
            'capability_type'     => 'post',
            'capabilities'        => array(
            'create_posts' => 'do_not_allow',
        ),
            'map_meta_cap'        => true,
            'has_archive'         => false,
            'hierarchical'        => false,
            'menu_position'       => 20,
            'supports'            => array( null ),
        );
        register_post_type( 'lwp_form_submission', $args );
    }
    
    //===========================================================================================
    /**
     * Disables the quick edit action for form submission posts.
     *
     * @param array $actions An array of post row actions.
     * @return array The updated array of post row actions.
     */
    function disable_quick_edit_form_submission( $actions )
    {
        global  $post ;
        if ( $post->post_type == 'lwp_form_submission' ) {
            unset( $actions['inline hide-if-no-js'] );
        }
        return $actions;
    }
    
    //===========================================================================================
    /**
     * Adds a notice to the free version of plugin on the single post page
     */
    function free_version_notice()
    {
        global  $pagenow, $typenow ;
        if ( $pagenow == 'post.php' && $typenow == 'lwp_form_submission' ) {
            echo  '<div class="notice notice-info">
					<p>Free version: Only form fields with Field ID "name", "email", and "message" are saved upon form submission. Upgrade for full features. <a href="' . esc_url( lwp_cfdd_fs()->get_upgrade_url() ) . '">Upgrade Now!</a></p>
				</div>' ;
        }
    }

}